pub struct Nrlmsise00Flags {Show 18 fields
pub geomagnetic: GeomagneticMode,
pub f107_solar_flux: bool,
pub time_independent: bool,
pub annual_harmonics: bool,
pub semiannual_harmonics: bool,
pub diurnal_tides: bool,
pub semidiurnal_tides: bool,
pub terdiurnal_tides: bool,
pub ut_and_longitude: bool,
pub exospheric_temp_variations: bool,
pub lower_boundary_temp_variations: bool,
pub gradient_variations: bool,
pub departures_from_diffusive_equilibrium: bool,
pub lower_thermosphere_temp_variations: bool,
pub upper_stratosphere_temp_variations: bool,
pub boundary_density_variations: bool,
pub lower_mesosphere_temp_variations: bool,
pub turbopause_scale_height_variations: bool,
}Fields
geomagnetic: GeomagneticModef107_solar_flux: booltime_independent: boolannual_harmonics: boolsemiannual_harmonics: booldiurnal_tides: boolsemidiurnal_tides: boolterdiurnal_tides: boolut_and_longitude: boolexospheric_temp_variations: boollower_boundary_temp_variations: boolgradient_variations: booldepartures_from_diffusive_equilibrium: boollower_thermosphere_temp_variations: boolupper_stratosphere_temp_variations: boolboundary_density_variations: boollower_mesosphere_temp_variations: boolturbopause_scale_height_variations: boolTrait Implementations
Sourceimpl Clone for Nrlmsise00Flags
impl Clone for Nrlmsise00Flags
Sourcefn clone(&self) -> Nrlmsise00Flags
fn clone(&self) -> Nrlmsise00Flags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Nrlmsise00Flags
Sourceimpl Debug for Nrlmsise00Flags
impl Debug for Nrlmsise00Flags
Sourceimpl Default for Nrlmsise00Flags
impl Default for Nrlmsise00Flags
impl DerefToPyAny for Nrlmsise00Flags
Sourceimpl<'de> Deserialize<'de> for Nrlmsise00Flags
impl<'de> Deserialize<'de> for Nrlmsise00Flags
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Nrlmsise00Flags
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for Nrlmsise00Flagswhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for Nrlmsise00Flagswhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for Nrlmsise00Flags
impl<'py> IntoPyObject<'py> for Nrlmsise00Flags
Sourcetype Target = Nrlmsise00Flags
type Target = Nrlmsise00Flags
The Python output type
Sourcetype Output = Bound<'py, <Nrlmsise00Flags as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <Nrlmsise00Flags as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for Nrlmsise00Flags
impl PartialEq for Nrlmsise00Flags
Sourceimpl PyClass for Nrlmsise00Flags
impl PyClass for Nrlmsise00Flags
Sourceimpl PyClassImpl for Nrlmsise00Flags
impl PyClassImpl for Nrlmsise00Flags
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<Nrlmsise00Flags as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<Nrlmsise00Flags>
type Layout = <<Nrlmsise00Flags as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<Nrlmsise00Flags>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForNrlmsise00Flags
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for Nrlmsise00Flags
impl PyClassNewTextSignature for Nrlmsise00Flags
const TEXT_SIGNATURE: &'static str = "(geomagnetic=None, f107_solar_flux=True, time_independent=True, annual_harmonics=True, semiannual_harmonics=True, diurnal_tides=True, semidiurnal_tides=True, terdiurnal_tides=True, ut_and_longitude=True, exospheric_temp_variations=True, lower_boundary_temp_variations=True, gradient_variations=True, departures_from_diffusive_equilibrium=True, lower_thermosphere_temp_variations=True, upper_stratosphere_temp_variations=True, boundary_density_variations=True, lower_mesosphere_temp_variations=True, turbopause_scale_height_variations=True)"
Sourceimpl PyTypeInfo for Nrlmsise00Flags
impl PyTypeInfo for Nrlmsise00Flags
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for Nrlmsise00Flags
impl Serialize for Nrlmsise00Flags
Sourceimpl StaticType for Nrlmsise00Flags
impl StaticType for Nrlmsise00Flags
Sourcefn static_type() -> SimpleType
fn static_type() -> SimpleType
Return the Dhall type that represents this type. Read more
impl StructuralPartialEq for Nrlmsise00Flags